# PGAA - Pygame-CE Anti-Aliasing

> [!NOTE]
> This project is very new and still under development. Expect bugs, issues, and incomplete features.
> This project is not affiliated with the Pygame-CE project.

## Dowload and Install

> [!CAUTION]
> No download is currently available. But in the future, you will be able to download the latest release from the [Releases](https://github.com/Iron-Sparrow/PGAA/releases) or by using pip.
